==> jtools-nodejs-1.2.15.tgz: package/Texto.js <==
"use strict";
var TextoPad = /** @class */ (function () {
    function TextoPad(tamanho, letra) {
        if (letra === void 0) { letra = '0'; }
        this.tamanho = tamanho;
        this.letra = letra;
    }
    TextoPad.prototype.pad = function () {
        var _retorno = '';
        for (var i = 0; i < this.tamanho; i++) {
            _retorno += this.letra;
        }
        return _retorno;
    };
    TextoPad.prototype.padEsquerda = function (texto) {
        texto = texto || '';
        var _strPad = this.pad();
        return _strPad.substring(0, _strPad.length - texto.length) + texto;
    };
    TextoPad.prototype.padDireita = function (texto) {
        texto = texto || '';
        var _strPad = this.pad();
        return texto + _strPad.substring(0, _strPad.length - texto.length);
    };
    return TextoPad;
}());
var Texto = /** @class */ (function () {
    function Texto() {
    }
    Texto.preencido = function (texto) {
        if (!texto || (texto == null))
            return false;
        else
            return true;
    };
    Texto.vazio = function (texto, trim) {
        if (trim === void 0) { trim = true; }
        if (!this.preencido(texto))
            return true;
        else {
            if (trim === true)
                texto = texto.trim();
            return texto.length == 0;
        }
    };
    Texto.tamanho = function (texto, trim) {
        if (trim === void 0) { trim = true; }
        if (!this.preencido(texto))
            return 0;
        else {
            if (trim === true)
                texto = texto.trim();
            return texto.length;
        }
    };
    Texto.limpa = function (texto) {
        if (this.vazio(texto))
            return '';
        else
            return texto.trim();
    };
    Texto.Pad = TextoPad;
    return Texto;
}());
module.exports = Texto;

==> jtools-nodejs-1.2.17.tgz: package/Texto.js <==
var TextoPad = (function () {
    function TextoPad(tamanho, letra) {
        if (typeof letra === "undefined") { letra = '0'; }
        this.tamanho = tamanho;
        this.letra = letra;
    }
    TextoPad.prototype.pad = function () {
        var _retorno = '';
        for (var i = 0; i < this.tamanho; i++) {
            _retorno += this.letra;
        }
        return _retorno;
    };
    TextoPad.prototype.padEsquerda = function (texto) {
        texto = texto || '';
        var _strPad = this.pad();
        return _strPad.substring(0, _strPad.length - texto.length) + texto;
    };
    TextoPad.prototype.padDireita = function (texto) {
        texto = texto || '';
        var _strPad = this.pad();
        return texto + _strPad.substring(0, _strPad.length - texto.length);
    };
    return TextoPad;
})();

var Texto = (function () {
    function Texto() {
    }
    Texto.preencido = function (texto) {
        if (!texto || (texto == null))
            return false;
        else
            return true;
    };
    Texto.vazio = function (texto, trim) {
        if (typeof trim === "undefined") { trim = true; }
        if (!this.preencido(texto))
            return true;
        else {
            if (trim === true)
                texto = texto.trim();
            return texto.length == 0;
        }
    };
    Texto.tamanho = function (texto, trim) {
        if (typeof trim === "undefined") { trim = true; }
        if (!this.preencido(texto))
            return 0;
        else {
            if (trim === true)
                texto = texto.trim();
            return texto.length;
        }
    };
    Texto.limpa = function (texto) {
        if (this.vazio(texto))
            return '';
        else
            return texto.trim();
    };
    Texto.Pad = TextoPad;
    return Texto;
})();

module.exports = Texto;
